@@ -10,9 +10,9 @@
 # %% Libraries
 import os
 import copy
-import wget
 import zipfile
 import itertools
+import requests
 import pandas as pd
 import numpy as np
 import networkx as nx
@@ -26,7 +26,6 @@ from decimal import Decimal
 from pgmpy.models import BayesianNetwork, NaiveBayes
 from pgmpy.factors.discrete import TabularCPD
 from pgmpy.sampling import BayesianModelSampling, GibbsSampling
-from pgmpy import readwrite
 from pgmpy.metrics import structure_score
 
 from ismember import ismember
@@ -585,9 +584,10 @@ def _bif2bayesian(pathname, verbose=3):
     >>> reader.get_model()
     <pgmpy.models.BayesianNetwork object at 0x7f20af154320>
     """
+    from pgmpy.readwrite import BIFReader
     if verbose>=3: print('[bnlearn] >Loading bif file <%s>' %(pathname))
 
-    bifmodel=readwrite.BIF.BIFReader(path=pathname)
+    bifmodel = BIFReader(path=pathname)
 
     try:
         model = BayesianNetwork(bifmodel.variable_edges)
@@ -1012,7 +1012,7 @@ def plot(model,
     >>>
 
     """
-    ax = None
+    fig = None
     # Check whether edges are available
     if model['adjmat'].sum().sum()==0:
         if verbose>=3: print('[bnlearn]> Nothing to plot because no edges are present between nodes. ')
@@ -1075,13 +1075,14 @@ def plot(model,
     # Plot
     if interactive:
         # Make interactive plot
-        ax = _plot_interactive(model, params_interactive, nodelist, node_colors, node_sizes, edgelist, edge_colors, edge_weights, title, verbose=verbose)
+        fig = _plot_interactive(model, params_interactive, nodelist, node_colors, node_sizes, edgelist, edge_colors, edge_weights, title, verbose=verbose)
     else:
         # Make static plot
-        ax = _plot_static(model, params_static, nodelist, node_colors, node_sizes, G, pos, edge_colors, edge_weights, visible=params_static['visible'])
+        fig = _plot_static(model, params_static, nodelist, node_colors, node_sizes, G, pos, edge_colors, edge_weights, visible=params_static['visible'])
 
     # Store
-    out['ax']=ax
+    out['fig']=fig
+    out['ax']=fig  # Should be removed in later releases
     out['pos']=pos
     out['G']=G
     out['node_properties']=node_properties
@@ -1093,7 +1094,7 @@ def plot(model,
 # def _plot_static(model, params_static, nodelist, node_colors, node_sizes, title, verbose=3):
 def _plot_static(model, params_static, nodelist, node_colors, node_sizes, G, pos, edge_colors, edge_weights, visible=True):
     # Bootup figure
-    ax = plt.figure(figsize=params_static['figsize'], facecolor=params_static['facecolor'])
+    fig = plt.figure(figsize=params_static['figsize'], facecolor=params_static['facecolor'])
     # nodes
     nx.draw_networkx_nodes(G, pos, nodelist=nodelist, node_size=node_sizes, alpha=params_static['alpha'], node_color=node_colors, node_shape=params_static['node_shape'])
     # edges
@@ -1104,10 +1105,12 @@ def _plot_static(model, params_static, nodelist, node_colors, node_sizes, G, pos
     # Plot text of the weights
     # nx.draw_networkx_edge_labels(G, pos, edge_labels=nx.get_edge_attributes(G, 'weight'), font_color=params_static['font_color'])
     # Making figure nice
-    # ax = plt.gca()
-    # ax.set_axis_off()
-    ax.set_visible(visible)
-    return ax
+    # fig = plt.gca()
+    # fig.set_axis_off()
+    if visible:
+        plt.show()
+    # Return
+    return fig
 
 
 # %% Plot interactive
@@ -1308,7 +1311,7 @@ def _download_example(data, verbose=3):
     # Check file exists.
     if not os.path.isfile(PATH_TO_DATA):
         if verbose>=3: print('[bnlearn] >Downloading example [%s] dataset..' %(data))
-        wget.download(url, curpath)
+        wget.download(url, PATH_TO_DATA)
 
     return PATH_TO_DATA
 
@@ -1344,9 +1347,9 @@ def import_DAG(filepath='sprinkler', CPD=True, checkmodel=True, verbose=3):
 
     """
     PATH_TO_DATA = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'data')
-    out={}
-    model=None
-    filepath=filepath.lower()
+    out = {}
+    model = None
+    filepath= filepath.lower()
     if verbose>=3: print('[bnlearn] >Import <%s>' %(filepath))
 
     # Load data
@@ -1385,7 +1388,7 @@ def import_DAG(filepath='sprinkler', CPD=True, checkmodel=True, verbose=3):
 def _unzip(getZip, ext='.bif', verbose=3):
     if not os.path.isdir(getZip):
         if verbose>=3: print('[bnlearn] >Extracting files..')
-        [pathname, _] = os.path.split(getZip)
+        pathname, _ = os.path.split(getZip)
         # Unzip
         zip_ref = zipfile.ZipFile(getZip, 'r')
         zip_ref.extractall(pathname)
@@ -1815,3 +1818,32 @@ def structure_scores(model, df, scoring_method=['k2', 'bds', 'bic', 'bdeu'], ver
                     show_message=False
     # Return
     return scores
+
+
+# %% Retrieve files files.
+class wget:
+    """Retrieve file from url."""
+
+    def filename_from_url(url):
+        """Return filename."""
+        return os.path.basename(url)
+
+    def download(url, writepath):
+        """Download.
+
+        Parameters
+        ----------
+        url : str.
+            Internet source.
+        writepath : str.
+            Directory to write the file.
+
+        Returns
+        -------
+        None.
+
+        """
+        r = requests.get(url, stream=True)
+        with open(writepath, "wb") as fd:
+            for chunk in r.iter_content(chunk_size=1024):
+                fd.write(chunk)
