@@ -6,6 +6,17 @@ from pgmpy.estimators import ExhaustiveSearch, HillClimbSearch, TreeSearch
 from pgmpy.factors.discrete import TabularCPD
 
 
+# %%
+
+import bnlearn as bn
+shapes = [(10000, 37), (10000, 223), (10000, 8), (10000, 11), (10000, 32), (352, 3)]
+for i, data in enumerate(['alarm', 'andes', 'asia', 'sachs', 'water', 'stormofswords']):
+    print(data)
+    df = bn.import_example(data=data)
+    assert df.shape==shapes[i]
+    
+
+
 # %% Notebook example
 # Example dataframe sprinkler_data.csv can be loaded with: 
 import bnlearn as bn
@@ -70,8 +81,7 @@ import bnlearn as bn
 model = bn.import_DAG('sprinkler', CPD=True)
 df = bn.sampling(model, n=1000, methodtype='bayes')
 fig = bn.plot(model, params_static={'visible': True})
-
-fig2 = bn.plot(model, interactive=True)
+fig2 = bn.plot(model, interactive=False)
 
 
 # %% Issue Mail:
@@ -534,6 +544,7 @@ model = bn.independence_test(model, df, prune=True)
 bn.plot(model)
 
 # %% Naive Bayesian model
+from pgmpy.factors.discrete import TabularCPD
 
 edges = [('A', 'B'), ('A', 'C'), ('A', 'D')]
 DAG = bn.make_DAG(edges, methodtype='naivebayes')
@@ -1145,6 +1156,7 @@ adjmat = bn.vec2adjmat(vector['source'], vector['target'])
 
 # %%
 import bnlearn as bn
+from pgmpy.factors.discrete import TabularCPD
 
 edges = [('A', 'E'),
          ('S', 'E'),
